@@ -2,11 +2,13 @@ package Data::Sah::CoerceCommon;
 
 our $DATE = '2019-11-28'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.038'; # VERSION
+our $VERSION = '0.039'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
 
+our $SUPPORT_OLD_PREFIX = $ENV{PERL_DATA_SAH_COERCE_SUPPORT_OLD_PREFIX} // 1;
+
 our %Default_Rules = (
     perl => {
         bool       => [qw//],
@@ -142,7 +144,7 @@ sub get_coerce_rules {
     my @rule_names = @{ $Default_Rules{$compiler}{$typen} || [] };
     for my $item (@{ $args{coerce_rules} // [] }) {
         my $is_exclude = $item =~ s/\A!//;
-        if ($item =~ /\A\w+\z/) {
+        if ($SUPPORT_OLD_PREFIX && $item =~ /\A\w+\z/) {
             # old name
         } elsif ($item =~ /\AFrom_[A-Za-z0-9_]+::[A-Za-z0-9_]+\z/) {
             # new name
@@ -159,7 +161,7 @@ sub get_coerce_rules {
 
     my @rules;
     for my $rule_name (@rule_names) {
-        my $is_old_name = $rule_name =~ /\A\w+\z/;
+        my $is_old_name = $SUPPORT_OLD_PREFIX && $rule_name =~ /\A\w+\z/;
         my $mod = ($is_old_name ? $old_prefix : $prefix) . $rule_name;
         (my $mod_pm = "$mod.pm") =~ s!::!/!g;
         require $mod_pm;
@@ -229,7 +231,7 @@ Data::Sah::CoerceCommon - Common stuffs for Data::Sah::Coerce and Data::Sah::Coe
 
 =head1 VERSION
 
-This document describes version 0.038 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2019-11-28.
+This document describes version 0.039 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2019-11-28.
 
 =head1 FUNCTIONS
 
@@ -304,6 +306,13 @@ that contains extra information.
 
 Return value:  (any)
 
+=head1 ENVIRONMENT
+
+=head2 PERL_DATA_SAH_COERCE_SUPPORT_OLD_PREFIX
+
+If set to false, will not support old prefix
+(Data::Sah::Coerce::<$TARGET_TYPE>::<$SOURCE_TYPE_AND_DESC>. Mainly for testing.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-Coerce>.
